==> igniteui-react-charts-16.6.8.tgz: package/ES5/StandardDeviationIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StandardDeviationIndicatorStrategy } from "./StandardDeviationIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var StandardDeviationIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(StandardDeviationIndicator, _super);
    function StandardDeviationIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicator.prototype.get_p5 = function () {
        return new StandardDeviationIndicatorStrategy();
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    StandardDeviationIndicator.prototype.get_qi = function () {
        return StandardDeviationIndicator.$;
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StandardDeviationIndicator.prototype, "qq", {
        get: function () {
            return typeGetValue(this.c(StandardDeviationIndicator.qr));
        },
        set: function (a) {
            this.h(StandardDeviationIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    StandardDeviationIndicator.prototype.qb = function () {
        return this.qq;
    };
    StandardDeviationIndicator.prototype.qk = function (a) {
        this.qq = a;
    };
    StandardDeviationIndicator.$t = markType(StandardDeviationIndicator, 'StandardDeviationIndicator', StrategyBasedIndicator.$);
    StandardDeviationIndicator.qr = StrategyBasedIndicator.qn(20, StandardDeviationIndicator.$);
    return StandardDeviationIndicator;
}(StrategyBasedIndicator));
export { StandardDeviationIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/StandardDeviationIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StandardDeviationIndicatorStrategy } from "./StandardDeviationIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var StandardDeviationIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(StandardDeviationIndicator, _super);
    function StandardDeviationIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicator.prototype.get_qc = function () {
        return new StandardDeviationIndicatorStrategy();
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    StandardDeviationIndicator.prototype.get_qp = function () {
        return StandardDeviationIndicator.$;
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StandardDeviationIndicator.prototype, "qx", {
        get: function () {
            return typeGetValue(this.c(StandardDeviationIndicator.qy));
        },
        set: function (a) {
            this.h(StandardDeviationIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    StandardDeviationIndicator.prototype.qi = function () {
        return this.qx;
    };
    StandardDeviationIndicator.prototype.qr = function (a) {
        this.qx = a;
    };
    StandardDeviationIndicator.$t = markType(StandardDeviationIndicator, 'StandardDeviationIndicator', StrategyBasedIndicator.$);
    StandardDeviationIndicator.qy = StrategyBasedIndicator.qu(20, StandardDeviationIndicator.$);
    return StandardDeviationIndicator;
}(StrategyBasedIndicator));
export { StandardDeviationIndicator };
